@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/clients/include/argus_def.h#52 $
- * $DateTime: 2014/05/12 10:49:40 $
- * $Change: 2818 $
+ * $Id: //depot/argus/clients/include/argus_def.h#55 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 /* Argus_def.h */
@@ -1573,13 +1573,18 @@ extern "C" {
 #define ARGUS_DST_CONGESTED           	0x00008000
 
 
-#define ARGUS_PKTS_DROP                  0x30
-#define ARGUS_SRC_PKTS_DROP              0x10
-#define ARGUS_DST_PKTS_DROP              0x20
+#define ARGUS_PKTS_DROP                 0x30
+#define ARGUS_SRC_PKTS_DROP             0x10
+#define ARGUS_DST_PKTS_DROP             0x20
 
-#define ARGUS_OUTOFORDER			0x00030000
-#define ARGUS_SRC_OUTOFORDER    		0x00010000
-#define ARGUS_DST_OUTOFORDER    		0x00020000
+#define ARGUS_OUTOFORDER		0x00030000
+#define ARGUS_SRC_OUTOFORDER    	0x00010000
+#define ARGUS_DST_OUTOFORDER    	0x00020000
+
+
+#define ARGUS_DUPLICATES                0x000C0000
+#define ARGUS_SRC_DUPLICATES            0x00040000
+#define ARGUS_DST_DUPLICATES            0x00080000
 
 #define ARGUS_TCP_OPTIONS		0xFFF00000
 #define ARGUS_TCP_MAXSEG		0x00100000
