@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2012 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus-3.0.6/clients/include/argus_metric.h#1 $
- * $DateTime: 2012/04/17 12:22:02 $
- * $Change: 2368 $
+ * $Id: //depot/argus/clients/include/argus_metric.h#36 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 #ifndef ArgusMetric_h
@@ -32,8 +32,8 @@
 extern "C" {
 #endif
 
-#define ARGUS_MAX_METRIC_ALG		113
-#define MAX_METRIC_ALG_TYPES		113
+#define ARGUS_MAX_METRIC_ALG		115
+#define MAX_METRIC_ALG_TYPES		115
 
 
 struct ArgusFetchValueStruct {
@@ -103,6 +103,9 @@ double ArgusFetchDstPktsCount (struct ArgusRecordStruct *ns);
 double ArgusFetchAppByteCount (struct ArgusRecordStruct *ns);
 double ArgusFetchSrcAppByteCount (struct ArgusRecordStruct *ns);
 double ArgusFetchDstAppByteCount (struct ArgusRecordStruct *ns);
+
+double ArgusFetchAppByteRatio (struct ArgusRecordStruct *ns);
+
 double ArgusFetchSrcTcpBase (struct ArgusRecordStruct *ns);
 double ArgusFetchDstTcpBase (struct ArgusRecordStruct *ns);
 double ArgusFetchTcpRtt (struct ArgusRecordStruct *ns);
@@ -112,6 +115,10 @@ double ArgusFetchSrcTcpMax (struct ArgusRecordStruct *ns);
 double ArgusFetchDstTcpMax (struct ArgusRecordStruct *ns);
 double ArgusFetchSrcGap (struct ArgusRecordStruct *ns);
 double ArgusFetchDstGap (struct ArgusRecordStruct *ns);
+/*
+double ArgusFetchSrcDup (struct ArgusRecordStruct *ns);
+double ArgusFetchDstDup (struct ArgusRecordStruct *ns);
+*/
 
 double ArgusFetchSrcIntPkt (struct ArgusRecordStruct *ns);
 double ArgusFetchSrcIntPktAct (struct ArgusRecordStruct *ns);
@@ -407,6 +414,17 @@ RaFetchAlgorithmTable[ARGUS_MAX_METRIC_ALG] = {
    {"dintpktactmax", ArgusFetchDstIntPktActMax},
 #define ARGUSMETRICDSTINTPKTIDLMAX  112
    {"dintpktidlmax", ArgusFetchDstIntPktIdlMax},
+
+#define ARGUSMETRICAPPBYTERATIO  113
+   {"abr", ArgusFetchAppByteRatio},
+#define ARGUSMETRICPRODUCERCONSUMERRATIO  114
+   {"pcr", ArgusFetchAppByteRatio},
+/*
+#define ARGUSMETRICSRCDUP  115
+   {"sdup", ArgusFetchSrcDup},
+#define ARGUSMETRICDSTDUP  116
+   {"ddup", ArgusFetchDstDup},
+*/
 };
 
 #else
@@ -465,6 +483,9 @@ extern double ArgusFetchDstPktsCount (struct ArgusRecordStruct *ns);
 extern double ArgusFetchAppByteCount (struct ArgusRecordStruct *ns);
 extern double ArgusFetchSrcAppByteCount (struct ArgusRecordStruct *ns);
 extern double ArgusFetchDstAppByteCount (struct ArgusRecordStruct *ns);
+
+extern double ArgusFetchAppByteRatio (struct ArgusRecordStruct *ns);
+
 extern double ArgusFetchSrcTcpBase (struct ArgusRecordStruct *ns);
 extern double ArgusFetchDstTcpBase (struct ArgusRecordStruct *ns);
 extern double ArgusFetchTcpRtt (struct ArgusRecordStruct *ns);
