@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/clients/include/argus_os.h#21 $
- * $DateTime: 2014/05/12 10:49:40 $
- * $Change: 2818 $
+ * $Id: //depot/argus/clients/include/argus_os.h#24 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 #ifndef ArgusOs_h
@@ -110,14 +110,56 @@ typedef uint64_t u_int64_t;
 
 #include <netinet/icmp6.h>
 
+#if !defined(ICMP6_DST_UNREACH_SRC_FAIL)
+#define ICMP6_DST_UNREACH_SRC_FAIL         5
+#endif
+#if !defined(ICMP6_DST_UNREACH_REJECT_ROUTE)
+#define ICMP6_DST_UNREACH_REJECT_ROUTE     6
+#endif
+#if !defined(ICMP6_DST_UNREACH_ERROR_SRC_ROUTE)
+#define ICMP6_DST_UNREACH_ERROR_SRC_ROUTE  7
+#endif
+
 #if !defined(ICMP6_MEMBERSHIP_QUERY)
-#define ICMP6_MEMBERSHIP_QUERY          130
+#define ICMP6_MEMBERSHIP_QUERY             130
 #endif
 #if !defined(ICMP6_MEMBERSHIP_REPORT)
-#define ICMP6_MEMBERSHIP_REPORT         131
+#define ICMP6_MEMBERSHIP_REPORT            131
 #endif
 #if !defined(ICMP6_MEMBERSHIP_REDUCTION)
-#define ICMP6_MEMBERSHIP_REDUCTION      132
+#define ICMP6_MEMBERSHIP_REDUCTION         132
+#endif
+
+
+#if !defined(ICMP6_MEMBERSHIP_REPORT_V2)
+#define ICMP6_MEMBERSHIP_REPORT_V2	   143
+#endif
+#if !defined(ICMP6_HOME_AGENT_ADDR_REQUEST)
+#define ICMP6_HOME_AGENT_ADDR_REQUEST      144
+#endif
+#if !defined(ICMP6_HOME_AGENT_ADDR_REPLY)
+#define ICMP6_HOME_AGENT_ADDR_REPLY	   145
+#endif
+#if !defined(ICMP6_MOBILE_PREFIX_SOL)
+#define ICMP6_MOBILE_PREFIX_SOL		146
+#endif
+#if !defined(ICMP6_MOBILE_PREFIX_ADV)
+#define ICMP6_MOBILE_PREFIX_ADV		147
+#endif
+#if !defined(ICMP6_CERT_PATH_SOL)
+#define ICMP6_CERT_PATH_SOL		148
+#endif
+#if !defined(ICMP6_CERT_PATH_ADV)
+#define ICMP6_CERT_PATH_ADV		149
+#endif
+#if !defined(ICMP6_EXPER_MOBILITY)
+#define ICMP6_EXPER_MOBILITY		150
+#endif
+#if !defined(ICMP6_MULTICAST_ROUTER_ADV)
+#define ICMP6_MULTICAST_ROUTER_ADV	151
+#endif
+#if !defined(ICMP6_MULTICAST_ROUTER_SOL)
+#define ICMP6_MULTICAST_ROUTER_SOL	152
 #endif
 
 #if !defined(linux)
