@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/clients/include/argus_out.h#54 $
- * $DateTime: 2014/05/12 10:49:40 $
- * $Change: 2818 $
+ * $Id: //depot/argus/clients/include/argus_out.h#57 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 
@@ -637,10 +637,10 @@ struct ArgusSystemFlow {
 
 #define   ipv6_flow flow_un.ipv6
 #define     ip_flow flow_un.ip
-#define  icmp6_flow flow_un.icmpv6
+#define icmpv6_flow flow_un.icmpv6
 #define   icmp_flow flow_un.icmp
 #define   igmp_flow flow_un.igmp
-#define  igmp6_flow flow_un.igmpv6
+#define igmpv6_flow flow_un.igmpv6
 #define    mac_flow flow_un.mac
 #define    arp_flow flow_un.arp
 #define   rarp_flow flow_un.rarp
